@@ -1,22 +1,34 @@
 /*
-    SPDX-FileCopyrightText: 2010 Tobias Koenig <tokoe@kde.org>
+    Copyright (c) 2010 Tobias Koenig <tokoe@kde.org>
 
-    SPDX-License-Identifier: LGPL-2.0-or-later
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
-#include "carddavprotocol_p.h"
-#include "libkdav_debug.h"
+#include "carddavprotocol.h"
 
-#include <QDomDocument>
-#include <QStringList>
-#include <QUrl>
+#include <QtCore/QStringList>
+#include <QtCore/QUrl>
+#include <QtCore/QVariant>
+#include <QtXml/QDomDocument>
 
 using namespace KDAV;
 
 class CarddavCollectionQueryBuilder : public XMLQueryBuilder
 {
 public:
-    QDomDocument buildQuery() const override
+    QDomDocument buildQuery() const Q_DECL_OVERRIDE
     {
         QDomDocument document;
 
@@ -33,7 +45,7 @@ public:
         return document;
     }
 
-    QString mimeType() const override
+    QString mimeType() const Q_DECL_OVERRIDE
     {
         return QString();
     }
@@ -42,7 +54,7 @@ public:
 class CarddavListItemsQueryBuilder : public XMLQueryBuilder
 {
 public:
-    QDomDocument buildQuery() const override
+    QDomDocument buildQuery() const Q_DECL_OVERRIDE
     {
         QDomDocument document;
 
@@ -59,7 +71,7 @@ public:
         return document;
     }
 
-    QString mimeType() const override
+    QString mimeType() const Q_DECL_OVERRIDE
     {
         return QStringLiteral("text/directory");
     }
@@ -68,7 +80,7 @@ public:
 class CarddavMultigetQueryBuilder : public XMLQueryBuilder
 {
 public:
-    QDomDocument buildQuery() const override
+    QDomDocument buildQuery() const Q_DECL_OVERRIDE
     {
         QDomDocument document;
         const QStringList urls = parameter(QStringLiteral("urls")).toStringList();
@@ -90,8 +102,7 @@ public:
         for (const QString &url : urls) {
             QDomElement hrefElement = document.createElementNS(QStringLiteral("DAV:"), QStringLiteral("href"));
             const QUrl pathUrl = QUrl::fromUserInput(url);
-            qCDebug(KDAV_LOG) << pathUrl.toString() << "->" << pathUrl.path();
-            const QDomText textNode = document.createTextNode(pathUrl.path());
+            const QDomText textNode = document.createTextNode(pathUrl.toString());
             hrefElement.appendChild(textNode);
 
             multigetElement.appendChild(hrefElement);
@@ -100,7 +111,7 @@ public:
         return document;
     }
 
-    QString mimeType() const override
+    QString mimeType() const Q_DECL_OVERRIDE
     {
         return QString();
     }
@@ -140,14 +151,16 @@ XMLQueryBuilder::Ptr CarddavProtocol::collectionsQuery() const
     return XMLQueryBuilder::Ptr(new CarddavCollectionQueryBuilder());
 }
 
-bool CarddavProtocol::containsCollection(const QDomElement &propElem) const
+QString CarddavProtocol::collectionsXQuery() const
 {
-    return !propElem.elementsByTagNameNS(QStringLiteral("urn:ietf:params:xml:ns:carddav"), QStringLiteral("addressbook")).isEmpty();
+    const QString query(QStringLiteral("//*[local-name()='addressbook' and namespace-uri()='urn:ietf:params:xml:ns:carddav']/ancestor::*[local-name()='response' and namespace-uri()='DAV:']"));
+
+    return query;
 }
 
-QList<XMLQueryBuilder::Ptr> CarddavProtocol::itemsQueries() const
+QVector<XMLQueryBuilder::Ptr> CarddavProtocol::itemsQueries() const
 {
-    QList<XMLQueryBuilder::Ptr> ret;
+    QVector<XMLQueryBuilder::Ptr> ret;
     ret << XMLQueryBuilder::Ptr(new CarddavListItemsQueryBuilder());
     return ret;
 }
